@@ -8,9 +8,11 @@ class TestErrorBasics(TestCase):
             av.open('does not exist')
         except AVError as e:
             self.assertEqual(e.errno, 2)
-            self.assertEqual(e.strerror, 'No such file or directory')
+            if is_windows:
+                self.assertEqual(e.strerror, 'Error number -2 occurred')
+            else:
+                self.assertEqual(e.strerror, 'No such file or directory')
             self.assertEqual(e.filename, 'does not exist')
-            self.assertEqual(str(e), "[Errno 2] No such file or directory: 'does not exist'")
         else:
             self.fail('no exception raised')
 
