@@ -9,24 +9,23 @@ from av import time_base as AV_TIME_BASE
 
 
 def timestamp_to_frame(timestamp, stream):
-    
     fps = stream.rate
     time_base = stream.time_base
     start_time = stream.start_time
-    
     frame = (timestamp - start_time ) * float(time_base) / float(fps)
     return frame
 
+
 def step_forward(container, stream):
-    
     for packet in container.demux(stream):
         for frame in packet.decode():
             if frame:
                 return frame
 
+
 class TestSeek(TestCase):
     def test_seek_start(self):
-        container = av.open(asset('320x240x4.mov'))
+        container = av.open(fate_suite('h264/interlaced_crop.mp4'))
 
         # count all the packets
         total_packet_count = 0 
@@ -44,7 +43,7 @@ class TestSeek(TestCase):
         self.assertEqual(total_packet_count, seek_packet_count)
         
     def test_seek_middle(self):
-        container = av.open(asset('320x240x4.mov'))
+        container = av.open(fate_suite('h264/interlaced_crop.mp4'))
         
         # count all the packets
         total_packet_count = 0 
@@ -62,7 +61,7 @@ class TestSeek(TestCase):
         self.assertTrue(seek_packet_count < total_packet_count)
         
     def test_seek_end(self):
-        container = av.open(asset('320x240x4.mov'))
+        container = av.open(fate_suite('h264/interlaced_crop.mp4'))
         
         # seek to middle
         container.seek(container.duration // 2)
@@ -84,7 +83,7 @@ class TestSeek(TestCase):
     
     def test_decode_half(self):
         
-        container = av.open(asset('320x240x4.mov'))
+        container = av.open(fate_suite('h264/interlaced_crop.mp4'))
         
         video_stream = next(s for s in container.streams if s.type == 'video')
         total_frame_count = 0
@@ -122,7 +121,7 @@ class TestSeek(TestCase):
     
     def test_stream_seek(self):
         
-        container = av.open(asset('320x240x4.mov'))
+        container = av.open(fate_suite('h264/interlaced_crop.mp4'))
         
         video_stream = next(s for s in container.streams if s.type == 'video')
         total_frame_count = 0
